==> ulyxex.1.1.6.alone.zip: pages/core/admin_page_modify.php <==
<?php
/* Ulyxex version 1.1.6 *****************/
class PageModify extends Admin {
	function __construct($pageId=Null){
		$this->h = New Html();
		$this->t = New Translate();
        $this->tree = New Tree();
		$this->page_id = $pageId;
		$this->Select = " SELECT ".
							PAGES.".*,".USERS.".USERNAME,".USERS.".ID USERID,".USERS.".USEROWNER";
		$this->From = 	" FROM ".
							PAGES.
							" INNER JOIN ".USERS. " ON ".PAGES.".USERID = ".USERS.".ID";
		$this->Cond = array();
	}
	public function update_page(){
		$hide = (isset($_POST['hide']))?1:0;
		$now = time();
		$date = date("Y-m-d H:i:s",$now);
		if (empty($_POST['name'])){return $this->h->h3($this->t->wr("title empty !"));}
		$query = "UPDATE ".PAGES." SET NAME = '".$this->h->safe($_POST['name'])."',".
									"PARENTID = '".$this->h->num($_POST['parent'])."',".
									"DESCRIPTION = '".$this->h->safe($_POST['content'])."',".
									"TYPEPAGE = '".$this->h->safe($_POST['type'])."',".
									"LINK = '".$this->h->safe($_POST['link'])."',".
									"SORTSTYLE = '".$this->h->num($_POST['sortstyle'])."',".
									"PAGEHEAD = '".$this->h->safe($_POST['head'])."',".
									"HIDE = '".$hide."'";
		$query .= isset($_POST['updateDate'])?",DATEPAGE = '".$date."'":"";
		if (isset($_POST['userid']) && $_POST['userid'] != $_POST['old_userid']) $query .=	",USERID = ".$this->h->num($_POST['userid']); // change userId
		$query .=					" WHERE ID = ".$this->page_id;
		if ($this->tree->pathTest($page=$this->page_id,$parent=$_POST['parent'])){
			$query = $this->q($query);
			return $this->h->h3($this->t->wx("page").strip_tags($_POST['name']).$this->t->wl("updated !"),"class='warning'");
		} else {
			return $this->h->h3($this->t->w("bad lineage !"),"class='warning'");
		}
	}
	public function data_page(){
		$h = $this->h;$t = $this->t;
		// 1) can create users etc.
		// 2) can create articles and pages
		// 3) can create articles everywhere
		// 4) can create articles only in sandbox
		switch ($_SESSION['level']){
			case 1: 
				if ($_SESSION['userid'] != 1){
					$this->Cond[] = "(".USERS.".USERLEVEL > ".$_SESSION['level']." OR ".USERS.".ID = ".$_SESSION['userid'].")"; // all level 2, 3 and 4 user's pages, user's pages 
					$this->Cond[] = USERS.".ID != 1"; // but not admin articles
				}
				$this->Cond[] = PAGES.".ID = ".$this->page_id;
				break;
			case 2:
				$this->Cond[] = PAGES.".ID = ".$this->page_id;
				break;
		}
		$query = $this->Select.$this->From.$this->Where($this->Cond);
		$query = $this->q($query);
		if ($dat = $this->fetch($query)){
			$sandboxParams = "";
			if ($dat['NAME'] == "SANDBOX"){
				$sandboxParams = "readonly='readonly'";
			}
			$_[] = $h->input("hidden","page",$dat['ID']);
			$_[] = $h->input("hidden","update",1);
			$params = ($dat['HIDE'])?" checked=\"checked\"":null;
            $_[] = $h->p( $t->w("sub page of").$this->tree->pathsSelect($dat['PARENTID']) );
			$_[] = $h->p("(id ".$dat['ID'].") ".$t->wr("hide").$h->input("checkbox","hide","on",$params));
			$options = array($t->w("date")=>0,$t->w("subject")=>1,$t->w("reverse date")=>2);
			$_[] = $h->p($t->w("sort articles by").$h->select($options,"sortstyle",$dat['SORTSTYLE']));
			$_[] = ($_SESSION['level'] == 1)?$h->input("hidden","old_userid",$dat['USERID']).$h->p($t->wr("choose user").$this->array_users($dat['USERID'])):Null;
			$_[] = $h->p($t->w("title")).$h->p($h->input("text","name",$h->uly_htmlentities($dat['NAME']),$sandboxParams." size=".FIELDWIDTH));
			$_[] = $h->p($t->w("head code (head tag)")).$h->p($h->textarea($dat['PAGEHEAD'],"head",array(4,FIELDWIDTH)));
			$_[] = $h->p( $t->w("type").$h->select($this->getTypes(),"set-type",$dat['TYPEPAGE'],"onchange='document.getElementById(\"type\").value=this.value'")." ".$h->input("text","type",$dat['TYPEPAGE']));
			$_[] = $h->p($t->w("link")).$h->p($h->input("text","link",$dat['LINK'],"size=".FIELDWIDTH));
			$_[] = $h->p($t->w("top content (description)")).$h->p($h->textarea($dat['DESCRIPTION'],"content",array(8,FIELDWIDTH)));
			$_[] = $h->p($t->wr("update date")."(".$dat['DATEPAGE'].")".$h->input("checkbox","updateDate","1"));
			$_[] = $h->p($h->input("submit","save",$t->w("update")));
			$inputs = implode("",$_);
			return $h->form($inputs,"page","post","admin.php?action=modify_page");
		} else {
			return $h->p("error");
		}
	}
}
?>

==> ulyxex.1.2.1.alone.zip: pages/core/admin_page_modify.php <==
<?php
/* Ulyxex version 1.2.1 *****************/
class PageModify extends Admin {
	function __construct($pageId=Null){
		$this->h = New Html();
		$this->t = New Translate();
        $this->tree = New Tree();
		$this->page_id = $pageId;
		$this->Select = " SELECT ".
							PAGES.".*,".USERS.".USERNAME,".USERS.".ID USERID,".USERS.".USEROWNER";
		$this->From = 	" FROM ".
							PAGES.
							" INNER JOIN ".USERS. " ON ".PAGES.".USERID = ".USERS.".ID";
		$this->Cond = array();
	}
	public function update_page(){
		$hide = (isset($_POST['hide']))?1:0;
		$now = time();
		$date = date("Y-m-d H:i:s",$now);
		if (empty($_POST['name'])){return $this->h->h3($this->t->wr("title empty !"));}
		$query = "UPDATE ".PAGES." SET NAME = '".$this->h->safe($_POST['name'])."',".
									"PARENTID = '".$this->h->num($_POST['parent'])."',".
									"DESCRIPTION = '".$this->h->safe($_POST['content'])."',".
									"TYPEPAGE = '".$this->h->safe($_POST['type'])."',".
									"LINK = '".$this->h->safe($_POST['link'])."',".
									"SORTSTYLE = '".$this->h->num($_POST['sortstyle'])."',".
									"PAGEHEAD = '".$this->h->safe($_POST['head'])."',".
									"HIDE = '".$hide."'";
		$query .= isset($_POST['updateDate'])?",DATEPAGE = '".$date."'":"";
		if (isset($_POST['userid']) && $_POST['userid'] != $_POST['old_userid']) $query .=	",USERID = ".$this->h->num($_POST['userid']); // change userId
		$query .=					" WHERE ID = ".$this->page_id;
		if ($this->tree->pathTest($page=$this->page_id,$parent=$_POST['parent'])){
			$query = $this->q($query);
			return $this->h->h3($this->t->wx("page").strip_tags($_POST['name']).$this->t->wl("updated !"),"class='warning'");
		} else {
			return $this->h->h3($this->t->w("bad lineage !"),"class='warning'");
		}
	}
	public function data_page(){
		$h = $this->h;$t = $this->t;
		// 1) can create users etc.
		// 2) can create articles and pages
		// 3) can create articles everywhere
		// 4) can create articles only in sandbox
		switch ($_SESSION['level']){
			case 1: 
				if ($_SESSION['userid'] != 1){
					$this->Cond[] = "(".USERS.".USERLEVEL > ".$_SESSION['level']." OR ".USERS.".ID = ".$_SESSION['userid'].")"; // all level 2, 3 and 4 user's pages, user's pages 
					$this->Cond[] = USERS.".ID != 1"; // but not admin articles
				}
				$this->Cond[] = PAGES.".ID = ".$this->page_id;
				break;
			case 2:
				$this->Cond[] = PAGES.".ID = ".$this->page_id;
				break;
		}
		$query = $this->Select.$this->From.$this->Where($this->Cond);
		$query = $this->q($query);
		if ($dat = $this->fetch($query)){
			$sandboxParams = "";
			if ($dat['NAME'] == "SANDBOX"){
				$sandboxParams = "readonly='readonly'";
			}
			$_[] = $h->input("hidden","page",$dat['ID']);
			$_[] = $h->input("hidden","update",1);
            $_[] = $h->p( $t->w("sub page of").$this->tree->pathsSelect($dat['PARENTID'],1,"page") );
			$options = array($t->w("date")=>0,$t->w("subject")=>1,$t->w("reverse date")=>2);
			$_[] = $h->p($t->w("sort articles by").$h->select($options,"sortstyle",$dat['SORTSTYLE']));
			$_[] = ($_SESSION['level'] == 1)?$h->input("hidden","old_userid",$dat['USERID']).$h->p($t->wr("choose user").$this->array_users($dat['USERID'])):Null;
			$params = ($dat['HIDE'])?" checked=\"checked\"":null;
			$_[] = $h->p($t->wr("hide").$h->input("checkbox","hide","on",$params).$t->wl("title")."(id ".$dat['ID'].")");
			$_[] = $h->p($h->input("text","name",$h->uly_htmlentities($dat['NAME']),$sandboxParams." size=".FIELDWIDTH));
			$_[] = $h->p($t->w("head code (head tag)")).$h->p($h->textarea($dat['PAGEHEAD'],"head",array(4,FIELDWIDTH)));
			$_[] = $h->p( $t->w("type").$h->select($this->getPageTypes(),"set-type",$dat['TYPEPAGE'],"onchange='document.getElementById(\"type\").value=this.value'")." ".$h->input("text","type",$dat['TYPEPAGE']));
			$_[] = $h->p($t->wr("if link").$h->input("text","link",$dat['LINK'],"size=".(FIELDWIDTH - 10)));
			$_[] = $h->p($t->w("top content (description)")).$h->p($h->textarea($dat['DESCRIPTION'],"content",array(8,FIELDWIDTH)));
			$_[] = $h->p($t->wr("update date")."(".$dat['DATEPAGE'].")".$h->input("checkbox","updateDate","1"));
			$_[] = $h->p($h->input("submit","save",$t->w("update")));
			$inputs = implode("",$_);
			return $h->form($inputs,"page","post","admin.php?action=modify_page");
		} else {
			return $h->p("error");
		}
	}
}
?>
